==> mobGameSDK-5.2.0.ad-sources.jar: com/game/sdk/comon/constants/ConstantTrackEvent.java <==
package com.game.sdk.comon.constants;

/**
 * Created by dungnv
 */

public interface ConstantTrackEvent {
    String START_TIME = "BEGIN_ACTION_TIME";
    String START_TIME_LOGIN = "BEGIN_ACTION_LOGIN_TIME";
    String START_TIME_CALL_API = "START_TIME_CALL_API";

    String START_CALL_GET_SDK_CONFIG = "ft_ls_game_config_call_api_success";

    String STR_EVENT_LAUNCHER = "ft_app_launched";
    String TRACK_FIRST_LAUNCH = "ft_first_launched";

    String TRACK_EXTRACT_STARTED = "ft_extract_started";
    String TRACK_EXTRACT_FINISHED = "ft_extract_finished";
    String TRACK_DOWNLOAD_RES_STARTED = "ft_resource_started";
    String TRACK_DOWNLOAD_RES_FINISHED = "ft_resource_finished";
    String TRACK_EXTRACT_CDN_FINISH = "ft_extract_cdn_finished";


    String TRACK_LOGOUT_SUCCESS = "ft_logout_success";
    String TRACK_APP_CLOSE = "ft_app_close";
    String TRACK_PURCHASE_LOG = "ft_purchase_log";

    String START_PERMISISON = "ft_start_permisison";
    String END_PERMISISON = "ft_end_permission";
    String TRACK_LICK_OVERLAY_PERMISTION = "ft_overlay_click_permission";

    String TRACK_LS_GET_SDK_CONFIG_SUCCESS = "ft_ls_game_config_call_api_success";
    String TRACK_LS_GET_SDK_CONFIG_FAILED = "ft_ls_game_config_call_api_fail";
    String TRACK_FT_SESSION = "ft_session";
    String TRACK_CLICK_BTN_ENTER_GAME = "ft_enter_game_btn_clicked";
    String TRACK_CHARACTER_CREATED = "ft_character_created";
    String TRACK_CHARACTER_CREATED_SUCCESS = "ft_character_created_call_api_success";
    String TRACK_CHARACTER_CREATED_FAIL = "ft_character_created_call_api_fail";
    String TRACK_VIP_ACHIEVED = "ft_vip_achieved";
    String TRACK_TUTORIAL_COMPLETION="af_tutorial_completion";
    String TRACK_LEVEL_ACHIEVED="af_level_achieved";

    //Login
    String TRACK_AF_LOGIN="af_login";
    String TRACK_FORM_LOGIN_OPENED = "ft_login_screen_opened";
    String TRACK_CLICK_BTN_LOGIN = "ft_ls_login_btn_clicked";
    String TRACK_CLICK_BTN_LOGIN_EMAIL = "ft_ls_login_email_btn_clicked";
    String TRACK_LOGIN_EMAIL_INPUT_ERR = "ft_ls_login_email_input_error";
    String TRACK_LS_LOGIN_EMAIL_CALL_API = "ft_ls_login_email_api_call";
    String TRACK_LS_LOGIN_EMAIL_CALL_API_SUCCESS = "ft_ls_login_email_api_call_success";
    String TRACK_LS_LOGIN_EMAIL_CALL_API_FAIL = "ft_ls_login_email_api_call_fail";

    String TRACK_LS_CLICK_BTN_LOGIN_FACEBOOK = "ft_ls_login_facebook_btn_clicked";
    String TRACK_LS_LOGIN_FACEBOOK_CANCEL = "ft_ls_login_facebook_user_canceled";
    String TRACK_LS_LOGIN_FACEBOOK_ERR = "ft_ls_login_facebook_have_error";
    String TRACK_LS_LOGIN_FACEBOOK_CALL_API = "ft_ls_login_facebook_api_call";
    String TRACK_LS_LOGIN_FACEBOOK_CALL_API_SUCCESS = "ft_ls_login_facebook_api_call_success";
    String TRACK_LS_LOGIN_FACEBOOK_CALL_API_FAIL = "ft_ls_login_facebook_api_call_fail";

    String TRACK_LS_CLICK_BTN_LOGIN_GOOGLE = "ft_ls_login_google_btn_clicked";
    String TRACK_LS_LOGIN_GOOGLE_CANCEL = "ft_ls_login_google_user_canceled";
    String TRACK_LS_LOGIN_GOOGLE_ERR = "ft_ls_login_google_have_error";
    String TRACK_LS_LOGIN_GOOGLE_CALL_API = "ft_ls_login_google_api_call";
    String TRACK_LS_LOGIN_GOOGLE_CALL_API_SUCCESS = "ft_ls_login_google_api_call_success";
    String TRACK_LS_LOGIN_GOOGLE_CALL_API_FAIL = "ft_ls_login_google_api_call_fail";

    String TRACK_LS_LOGIN_PLAYNOW_CALL_API = "ft_ls_login_playnow_btn_clicked";
    String TRACK_LS_LOGIN_PLAYNOW_CALL_API_SUCCESS = "ft_ls_login_playnow_api_call_success";
    String TRACK_LS_LOGIN_PLAYNOW_CALL_API_FAIL = "ft_ls_login_playnow_api_call_fail";

    String TRACK_LS_CLICK_BTN_REGISTER = "ft_ls_register_btn_clicked";
    String TRACK_LS_REGISTER_LOAD_SUCCESS = "ft_ls_register_form_load_success";
    String TRACK_LS_REGISTER_SUBMIT_FORM = "ft_ls_register_form_submited";
    String TRACK_LOGIN_SCREEN_CLOSE = "ft_ls_close_btn_clicked";

    String TRACK_LS_AUTHEN_FAILED = "ft_ls_get_authen_api_call_fail";
    String TRACK_LS_AUTHEN_SUCESS = "ft_ls_get_authen_api_call_success";
    String TRACK_LS_FORGOT_PASS = "ft_ls_forgot_password_btn_clicked";

    String LAST_SESSION_START = "LAST_SESSION_START";
    String LAST_SESSION_END = "LAST_SESSION_END";
    String LAST_SESSION_DETAl = "LAST_SESSION_DETAl";


    /**
     * PAYMENT------------------------------------------------------------------
     */

    String TRACK_LOAD_PAYMENT_SCREEN_OPENED = "ft_payment_screen_opened";
    String TRACK_LOAD_PAYMENT_SCREEN_SUCEESS = "ft_payment_screen_load_success";
    String TRACK_LOAD_PAYMENT_SCREEN_FAILED = "ft_payment_screen_load_fail";
    String TRACK_PAYMENT_BEFOR_VERIFY = "ft_payment_before_verify";
    String TRACK_PAYMENT_VERIFY_FAIL = "ft_payment_verify_fail";
    String TRACK_PURCHASE="af_purchase";
    String TRACK_MAINTAIN_SCREEN_OPENED="ft_maintain_screen_opened";

}

==> mobGameSDK-5.2.2.ad-sources.jar: com/game/sdk/comon/constants/ConstantTrackEvent.java <==
package com.game.sdk.comon.constants;

/**
 * Created by dungnv
 */

public interface ConstantTrackEvent {
    String START_TIME = "BEGIN_ACTION_TIME";
    String START_TIME_LOGIN = "BEGIN_ACTION_LOGIN_TIME";
    String START_TIME_CALL_API = "START_TIME_CALL_API";

    String START_CALL_GET_SDK_CONFIG = "ft_ls_game_config_call_api_success";

    String STR_EVENT_LAUNCHER = "ft_app_launched";
    String TRACK_FIRST_LAUNCH = "ft_first_launched";

    String TRACK_EXTRACT_STARTED = "ft_extract_started";
    String TRACK_EXTRACT_FINISHED = "ft_extract_finished";
    String TRACK_DOWNLOAD_RES_STARTED = "ft_resource_started";
    String TRACK_DOWNLOAD_RES_FINISHED = "ft_resource_finished";
    String TRACK_EXTRACT_CDN_FINISH = "ft_extract_cdn_finished";


    String TRACK_LOGOUT_SUCCESS = "ft_logout_success";
    String TRACK_APP_CLOSE = "ft_app_close";
    String TRACK_PURCHASE_LOG = "ft_purchase_log";

    String START_PERMISISON = "ft_start_permisison";
    String END_PERMISISON = "ft_end_permission";
    String TRACK_LICK_OVERLAY_PERMISTION = "ft_overlay_click_permission";

    String TRACK_LS_GET_SDK_CONFIG_SUCCESS = "ft_ls_game_config_call_api_success";
    String TRACK_LS_GET_SDK_CONFIG_FAILED = "ft_ls_game_config_call_api_fail";
    String TRACK_FT_SESSION = "ft_session";
    String TRACK_CLICK_BTN_ENTER_GAME = "ft_enter_game_btn_clicked";
    String TRACK_CHARACTER_CREATED = "ft_character_created";
    String TRACK_CHARACTER_CREATED_SUCCESS = "ft_character_created_call_api_success";
    String TRACK_CHARACTER_CREATED_FAIL = "ft_character_created_call_api_fail";
    String TRACK_VIP_ACHIEVED = "ft_vip_achieved";
    String TRACK_TUTORIAL_COMPLETION="af_tutorial_completion";
    String TRACK_LEVEL_ACHIEVED="af_level_achieved";

    //Login
    String TRACK_AF_LOGIN="af_login";
    String TRACK_FORM_LOGIN_OPENED = "ft_login_screen_opened";
    String TRACK_CLICK_BTN_LOGIN = "ft_ls_login_btn_clicked";
    String TRACK_CLICK_BTN_LOGIN_EMAIL = "ft_ls_login_email_btn_clicked";
    String TRACK_LOGIN_EMAIL_INPUT_ERR = "ft_ls_login_email_input_error";
    String TRACK_LS_LOGIN_EMAIL_CALL_API = "ft_ls_login_email_api_call";
    String TRACK_LS_LOGIN_EMAIL_CALL_API_SUCCESS = "ft_ls_login_email_api_call_success";
    String TRACK_LS_LOGIN_EMAIL_CALL_API_FAIL = "ft_ls_login_email_api_call_fail";

    String TRACK_LS_CLICK_BTN_LOGIN_FACEBOOK = "ft_ls_login_facebook_btn_clicked";
    String TRACK_LS_LOGIN_FACEBOOK_CANCEL = "ft_ls_login_facebook_user_canceled";
    String TRACK_LS_LOGIN_FACEBOOK_ERR = "ft_ls_login_facebook_have_error";
    String TRACK_LS_LOGIN_FACEBOOK_CALL_API = "ft_ls_login_facebook_api_call";
    String TRACK_LS_LOGIN_FACEBOOK_CALL_API_SUCCESS = "ft_ls_login_facebook_api_call_success";
    String TRACK_LS_LOGIN_FACEBOOK_CALL_API_FAIL = "ft_ls_login_facebook_api_call_fail";

    String TRACK_LS_CLICK_BTN_LOGIN_GOOGLE = "ft_ls_login_google_btn_clicked";
    String TRACK_LS_LOGIN_GOOGLE_CANCEL = "ft_ls_login_google_user_canceled";
    String TRACK_LS_LOGIN_GOOGLE_ERR = "ft_ls_login_google_have_error";
    String TRACK_LS_LOGIN_GOOGLE_CALL_API = "ft_ls_login_google_api_call";
    String TRACK_LS_LOGIN_GOOGLE_CALL_API_SUCCESS = "ft_ls_login_google_api_call_success";
    String TRACK_LS_LOGIN_GOOGLE_CALL_API_FAIL = "ft_ls_login_google_api_call_fail";

    String TRACK_LS_LOGIN_PLAYNOW_CALL_API = "ft_ls_login_playnow_btn_clicked";
    String TRACK_LS_LOGIN_PLAYNOW_CALL_API_SUCCESS = "ft_ls_login_playnow_api_call_success";
    String TRACK_LS_LOGIN_PLAYNOW_CALL_API_FAIL = "ft_ls_login_playnow_api_call_fail";

    String TRACK_LS_CLICK_BTN_REGISTER = "ft_ls_register_btn_clicked";
    String TRACK_LS_REGISTER_LOAD_SUCCESS = "ft_ls_register_form_load_success";
    String TRACK_LS_REGISTER_SUBMIT_FORM = "ft_ls_register_form_submited";
    String TRACK_LOGIN_SCREEN_CLOSE = "ft_ls_close_btn_clicked";

    String TRACK_LS_AUTHEN_FAILED = "ft_ls_get_authen_api_call_fail";
    String TRACK_LS_AUTHEN_SUCESS = "ft_ls_get_authen_api_call_success";
    String TRACK_LS_FORGOT_PASS = "ft_ls_forgot_password_clicked";

    String LAST_SESSION_START = "LAST_SESSION_START";
    String LAST_SESSION_END = "LAST_SESSION_END";
    String LAST_SESSION_DETAl = "LAST_SESSION_DETAl";


    /**
     * PAYMENT------------------------------------------------------------------
     */

    String TRACK_LOAD_PAYMENT_SCREEN_OPENED = "ft_payment_screen_opened";
    String TRACK_LOAD_PAYMENT_SCREEN_SUCEESS = "ft_payment_screen_load_success";
    String TRACK_LOAD_PAYMENT_SCREEN_FAILED = "ft_payment_screen_load_fail";
    String TRACK_PAYMENT_BEFOR_VERIFY = "ft_payment_before_verify";
    String TRACK_PAYMENT_VERIFY_FAIL = "ft_payment_verify_fail";
    String TRACK_PURCHASE="af_purchase";
    String TRACK_MAINTAIN_SCREEN_OPENED="ft_maintain_screen_opened";

}
